# listening_post_1379

<img src="imgs/lp1379.png" width="100" alt="lp1379">

This repository mainly acts as a bridge between [notify](https://github.com/notify-rs/notify) and python.
Ultimate goal is a _lightweight_ python importable function that watches a directory for changes.

```python
from lp1379.lp1379 import rswatcher
```

Example usage available under [examples](examples) folder.